MustHaveLowercaseValidation extension

Extension on LucidValidationBuilder for String properties to add a lowercase letter validation.

This extension adds a mustHaveLowercase method that can be used to ensure that a string contains at least one lowercase letter.

on

Methods

mustHaveLowercase({String? message, String? code}) SimpleValidationBuilder<String>

Available on SimpleValidationBuilder<String>, provided by the MustHaveLowercaseValidation extension

Adds a validation rule that checks if the String contains at least one lowercase letter.