ApiCallback class abstract

Text

Available extensions
Annotations
  • @freezed

Constructors

ApiCallback({required String name, required Map<String, PathItem> expression})
const
factory

Properties

copyWith → $ApiCallbackCopyWith<ApiCallback>
Create a copy of ApiCallback with the given fields replaced by the non-null parameter values.
no setterinherited
expression → Map<String, PathItem>
The callback expression to evaluate and operation to perform
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the callback
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ApiCallback value)) → TResult

Available on ApiCallback, provided by the ApiCallbackPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ApiCallback value)?) → TResult?

Available on ApiCallback, provided by the ApiCallbackPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ApiCallback value)?, {required TResult orElse()}) → TResult

Available on ApiCallback, provided by the ApiCallbackPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String name, Map<String, PathItem> expression)?, {required TResult orElse()}) → TResult

Available on ApiCallback, provided by the ApiCallbackPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String name, Map<String, PathItem> expression)) → TResult

Available on ApiCallback, provided by the ApiCallbackPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String name, Map<String, PathItem> expression)?) → TResult?

Available on ApiCallback, provided by the ApiCallbackPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited