Discriminator class abstract

Text

Available extensions
Annotations
  • @freezed

Constructors

Discriminator({required String propertyName, Map<String, String>? mapping})
const
factory
Discriminator.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $DiscriminatorCopyWith<Discriminator>
Create a copy of Discriminator with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
mapping → Map<String, String>?
An object to hold mappings between payload values and schema names or references.
no setterinherited
propertyName → String
The name of the property in the payload that will hold the discriminator value.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Discriminator value)) → TResult

Available on Discriminator, provided by the DiscriminatorPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Discriminator value)?) → TResult?

Available on Discriminator, provided by the DiscriminatorPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Discriminator value)?, {required TResult orElse()}) → TResult

Available on Discriminator, provided by the DiscriminatorPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String propertyName, Map<String, String>? mapping)?, {required TResult orElse()}) → TResult

Available on Discriminator, provided by the DiscriminatorPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this Discriminator to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String propertyName, Map<String, String>? mapping)) → TResult

Available on Discriminator, provided by the DiscriminatorPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String propertyName, Map<String, String>? mapping)?) → TResult?

Available on Discriminator, provided by the DiscriminatorPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited