License class abstract

Text

Available extensions
Annotations
  • @freezed

Constructors

License({required String name, String? identifier, String? url})
const
factory
License.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $LicenseCopyWith<License>
Create a copy of License with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
identifier → String?
An SPDX license expression for the API. The identifier field is mutually exclusive of the url field.
no setterinherited
name → String
The license name used for the API.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String?
A URL to the license used for the API. This must be in the form of a URL. The url field is mutually exclusive of the identifier field.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_License value)) → TResult

Available on License, provided by the LicensePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_License value)?) → TResult?

Available on License, provided by the LicensePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_License value)?, {required TResult orElse()}) → TResult

Available on License, provided by the LicensePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String name, String? identifier, String? url)?, {required TResult orElse()}) → TResult

Available on License, provided by the LicensePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this License to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String name, String? identifier, String? url)) → TResult

Available on License, provided by the LicensePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String name, String? identifier, String? url)?) → TResult?

Available on License, provided by the LicensePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited