OpenId class abstract

Open ID protocol configuration

Available extensions
Annotations
  • @freezed

Constructors

OpenId({String? issuer, @JsonKey.new(name: 'authorization_endpoint') String? authorizationEndpoint, @JsonKey.new(name: 'token_endpoint') String? tokenEndpoint, @JsonKey.new(name: 'device_authorization_endpoint') String? deviceAuthorizationEndpoint, @JsonKey.new(name: 'userinfo_endpoint') String? userinfoEndpoint, @JsonKey.new(name: 'mfa_challenge_endpoint') String? mfaChallengeEndpoint, @JsonKey.new(name: 'jwks_uri') String? jwksUri, @JsonKey.new(name: 'registration_endpoint') String? registrationEndpoint, @JsonKey.new(name: 'revocation_endpoint') String? revocationEndpoint, @JsonKey.new(name: 'scopes_supported') List<String>? scopesSupported, @JsonKey.new(name: 'response_types_supported') List<String>? responseTypesSupported, @JsonKey.new(name: 'code_challenge_methods_supported') List<String>? codeChallengeMethodsSupported, @JsonKey.new(name: 'response_modes_supported') List<String>? responseModesSupported, @JsonKey.new(name: 'subject_types_supported') List<String>? subjectTypesSupported, @JsonKey.new(name: 'id_token_signing_alg_values_supported') List<String>? idTokenSigningAlgValuesSupported, @JsonKey.new(name: 'token_endpoint_auth_methods_supported') List<String>? tokenEndpointAuthMethodsSupported, @JsonKey.new(name: 'claims_supported') List<String>? claimsSupported, @JsonKey.new(name: 'request_uri_parameter_supported') bool? requestUriParameterSupported, @JsonKey.new(name: 'request_parameter_supported') bool? requestParameterSupported, @JsonKey.new(name: 'token_endpoint_auth_signing_alg_values_supported') List<String>? tokenEndpointAuthSigningAlgValuesSupported})
const
factory
OpenId.fromJson(Map<String, dynamic> json)
factory

Properties

authorizationEndpoint → String?
Text
no setterinherited
claimsSupported → List<String>?
Text
no setterinherited
codeChallengeMethodsSupported → List<String>?
Text
no setterinherited
copyWith → $OpenIdCopyWith<OpenId>
Create a copy of OpenId with the given fields replaced by the non-null parameter values.
no setterinherited
deviceAuthorizationEndpoint → String?
Text
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
idTokenSigningAlgValuesSupported → List<String>?
Text
no setterinherited
issuer → String?
Text
no setterinherited
jwksUri → String?
Text
no setterinherited
mfaChallengeEndpoint → String?
Text
no setterinherited
registrationEndpoint → String?
Text
no setterinherited
requestParameterSupported → bool?
Text
no setterinherited
requestUriParameterSupported → bool?
Text
no setterinherited
responseModesSupported → List<String>?
Text
no setterinherited
responseTypesSupported → List<String>?
Text
no setterinherited
revocationEndpoint → String?
Text
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scopesSupported → List<String>?
Text
no setterinherited
subjectTypesSupported → List<String>?
Text
no setterinherited
tokenEndpoint → String?
Text
no setterinherited
tokenEndpointAuthMethodsSupported → List<String>?
Text
no setterinherited
tokenEndpointAuthSigningAlgValuesSupported → List<String>?
Text
no setterinherited
userinfoEndpoint → String?
Text
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_OpenId value)) → TResult

Available on OpenId, provided by the OpenIdPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_OpenId value)?) → TResult?

Available on OpenId, provided by the OpenIdPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_OpenId value)?, {required TResult orElse()}) → TResult

Available on OpenId, provided by the OpenIdPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? issuer, String? authorizationEndpoint, String? tokenEndpoint, String? deviceAuthorizationEndpoint, String? userinfoEndpoint, String? mfaChallengeEndpoint, String? jwksUri, String? registrationEndpoint, String? revocationEndpoint, List<String>? scopesSupported, List<String>? responseTypesSupported, List<String>? codeChallengeMethodsSupported, List<String>? responseModesSupported, List<String>? subjectTypesSupported, List<String>? idTokenSigningAlgValuesSupported, List<String>? tokenEndpointAuthMethodsSupported, List<String>? claimsSupported, bool? requestUriParameterSupported, bool? requestParameterSupported, List<String>? tokenEndpointAuthSigningAlgValuesSupported)?, {required TResult orElse()}) → TResult

Available on OpenId, provided by the OpenIdPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this OpenId to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? issuer, String? authorizationEndpoint, String? tokenEndpoint, String? deviceAuthorizationEndpoint, String? userinfoEndpoint, String? mfaChallengeEndpoint, String? jwksUri, String? registrationEndpoint, String? revocationEndpoint, List<String>? scopesSupported, List<String>? responseTypesSupported, List<String>? codeChallengeMethodsSupported, List<String>? responseModesSupported, List<String>? subjectTypesSupported, List<String>? idTokenSigningAlgValuesSupported, List<String>? tokenEndpointAuthMethodsSupported, List<String>? claimsSupported, bool? requestUriParameterSupported, bool? requestParameterSupported, List<String>? tokenEndpointAuthSigningAlgValuesSupported)) → TResult

Available on OpenId, provided by the OpenIdPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? issuer, String? authorizationEndpoint, String? tokenEndpoint, String? deviceAuthorizationEndpoint, String? userinfoEndpoint, String? mfaChallengeEndpoint, String? jwksUri, String? registrationEndpoint, String? revocationEndpoint, List<String>? scopesSupported, List<String>? responseTypesSupported, List<String>? codeChallengeMethodsSupported, List<String>? responseModesSupported, List<String>? subjectTypesSupported, List<String>? idTokenSigningAlgValuesSupported, List<String>? tokenEndpointAuthMethodsSupported, List<String>? claimsSupported, bool? requestUriParameterSupported, bool? requestParameterSupported, List<String>? tokenEndpointAuthSigningAlgValuesSupported)?) → TResult?

Available on OpenId, provided by the OpenIdPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited