SchemaGeneratorOptions class

Constructors

SchemaGeneratorOptions({bool singleFile = false, String? onSchemaName(String)?, String onSchemaUnionName(String, List<String>)?, String? onSchemaUnionKey(String, List<String>)?, String onSchemaPropertyName(String)?})
const

Properties

enabled → bool
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
onSchemaName → String? Function(String)?
final
onSchemaPropertyName → String Function(String)?
final
onSchemaUnionKey → String? Function(String, List<String>)?
final
onSchemaUnionName → String Function(String, List<String>)?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
singleFile → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited