Xml class abstract

Text

Available extensions
Annotations
  • @freezed

Constructors

Xml({String? name, String? namespace, String? prefix, bool? attribute, bool? wrapped})
const
factory
Xml.fromJson(Map<String, dynamic> json)
factory

Properties

attribute → bool?
Declares whether the property definition translates to an attribute instead of an element
no setterinherited
copyWith → $XmlCopyWith<Xml>
Create a copy of Xml with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
name → String?
Replaces the name of the element/attribute used for the described schema property
no setterinherited
namespace → String?
The URI of the namespace definition This must be in the form of an absolute URI.
no setterinherited
prefix → String?
The prefix to be used for the name.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wrapped → bool?
May be used only for an array definition
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Xml value)) → TResult

Available on Xml, provided by the XmlPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Xml value)?) → TResult?

Available on Xml, provided by the XmlPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Xml value)?, {required TResult orElse()}) → TResult

Available on Xml, provided by the XmlPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? name, String? namespace, String? prefix, bool? attribute, bool? wrapped)?, {required TResult orElse()}) → TResult

Available on Xml, provided by the XmlPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this Xml to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? name, String? namespace, String? prefix, bool? attribute, bool? wrapped)) → TResult

Available on Xml, provided by the XmlPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? name, String? namespace, String? prefix, bool? attribute, bool? wrapped)?) → TResult?

Available on Xml, provided by the XmlPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited