MustHaveLowercaseValidation extension
Extension on LucidValidationBuilder for String properties to add a lowercase letter validation.
This extension adds a mustHaveLowercase method that can be used to ensure that a string
contains at least one lowercase letter.
Methods
-
mustHaveLowercase(
{String? message, String? code}) → SimpleValidationBuilder< String> -
Available on SimpleValidationBuilder<
Adds a validation rule that checks if the String contains at least one lowercase letter.String> , provided by the MustHaveLowercaseValidation extension